@@ -89,12 +89,19 @@ class Build:
         """Actually build the package."""
 
         build_log = os.path.join(self.log_dir, "bench-build.log")
+        prebuild_log = os.path.join(self.log_dir, "bench-prebuild.log")
 
         distcc_log = os.path.join(self.log_dir, "bench-build-distcc.log")
 
         rm_files((build_log, distcc_log))
 
         print "** Building..."
+        if self.project.pre_build_cmd:
+            cmd = ("cd %s && %s > %s 2>&1" % (self.build_dir,
+                                              self.project.pre_build_cmd,
+                                              prebuild_log))
+            run_cmd(cmd)
+            
         cmd = ("cd %s && \\\n%s \\\nDISTCC_LOG='%s' \\\nCC='%s' \\\nCXX='%s' \\\n%s \\\n>%s 2>&1" % 
                (self.build_dir, self.project.build_cmd, distcc_log,
                 self.compiler.cc,
