@@ -40,6 +40,7 @@ class Project:
                  md5=None,
                  name=None,
                  configure_cmd=None,
+                 pre_build_cmd = None,
                  build_cmd=None,
                  unpacked_subdir=None,
                  build_subdir=None,
@@ -58,6 +59,7 @@ class Project:
         self.configure_cmd = configure_cmd or "./configure"
         self.build_cmd = build_cmd or "make"
         self.source_name = source_name or name
+        self.pre_build_cmd = pre_build_cmd
 
         self.package_dir = "packages"
         self.download_dir = "download"
