@@ -1,7 +1,7 @@
 # distcc/benchmark -- automated system for testing distcc correctness
 # and performance on various source trees.
 
-# Copyright (C) 2002, 2003 by Martin Pool
+# Copyright (C) 2002, 2003, 2004 by Martin Pool
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -22,9 +22,15 @@ __doc__ = """distcc benchmark project definitions"""
 
 from Project import Project
 
-Project(url = 'http://ftp.gnu.org/pub/gnu/glibc/glibc-2.3.1.tar.gz',
-        configure_cmd = './configure --disable-sanity-checks'
-        ).register()
+# Would like to test glibc, but it needs a separate source and build
+# directory, and this tool doesn't support that yet.  
+
+# disable-sanity-checks is needed to stop it wanting linuxthreads --
+# the resulting library is useless, but this is only a test.
+
+#Project(url = 'http://ftp.gnu.org/pub/gnu/glibc/glibc-2.3.2.tar.bz2',
+#        configure_cmd = './configure --disable-sanity-checks'
+#        ).register()
 
 #Project(url='http://mirror.aarnet.edu.au/pub/gnu/libc/glibc-2.3.tar.bz2',
 #        configure_cmd='./configure --disable-sanity-checks',
@@ -86,3 +92,10 @@ Project(url='http://ftp.mozilla.org/pub/firebird/releases/0.6/MozillaFirebird-0.
         name='MozillaFirebird',
         unpacked_subdir='mozilla',
         ).register()
+
+Project(url='http://us1.samba.org/samba/ftp/samba-3.0.7.tar.gz',
+        name='samba-3.0.7',
+        build_subdir='source',
+        configure_cmd='./configure',
+        pre_build_cmd = 'make proto', 
+        ).register()
