@@ -43,7 +43,7 @@ class Summary:
         import statistics
 
         # if nothing was run, skip it
-        if len(self._table):
+        if not len(self._table):
             return        
 
         """Print out in a nice tabular form"""
