@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -50,6 +50,9 @@
  * Simple IP-based access-control system
  */
 
+static const in_addr_t allones = 0xffffffffUL;
+
+
 /**
  * Interpret a "HOST/BITS" mask specification.  Return @p value and @p mask.
  **/
@@ -82,24 +85,20 @@ int dcc_parse_mask(const char *spec,
 
     mask_str = &spec[value_len + 1];
     if (spec[value_len] && *mask_str) {
-        /* find mask length */
+        /* find mask length as a number of bits */
         mask_bits = atoi(mask_str);
         if (mask_bits < 0 || mask_bits > 32) {
             rs_log_error("invalid mask \"%s\"", mask_str);
             return EXIT_BAD_ARGUMENTS;
         }
 
-        /*  make mask with the top mask_bits set.  
-         *
-         * NOTE: C99 says that rightshift by more than the length of the type
-         * is undefined.  (And indeed it fails on i386 because the SHR does
-         * not saturate.)  */
+        /* Make a network-endian mask with the top mask_bits set.  */
         if (mask_bits == 32)
-            *mask = (in_addr_t) ~0UL;
+            *mask = allones;
         else
-            *mask = htonl(~(~0UL >> mask_bits));
+            *mask = htonl(~(allones >> mask_bits));
     } else {
-        *mask = (in_addr_t) ~0UL;
+        *mask = allones;
     }
     return 0;
 }
