@@ -84,12 +84,10 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 #include "snprintf.h"
-#include "filename.h"
-#include "arg.h"
+
 
 static int dcc_argv_append(char *argv[], char *toadd)
 {
@@ -131,10 +129,12 @@ int dcc_scan_args(char *argv[], char **input_file, char **output_file,
     int ret;
 
      /* allow for -o foo.o */
-    if ((ret = dcc_shallowcopy_argv(argv, ret_newargv, 2)) != 0)
+    if ((ret = dcc_copy_argv(argv, ret_newargv, 2)) != 0)
         return ret;
     argv = *ret_newargv;
 
+    /* FIXME: new copy of argv is leaked */
+
     dcc_trace_argv("scanning arguments", argv);
 
     /* Things like "distcc -c hello.c" with an implied compiler are
@@ -181,6 +181,9 @@ int dcc_scan_args(char *argv[], char **input_file, char **output_file,
                     rs_trace("%s must be local", a);
                     return EXIT_DISTCC_FAILED;
                 }
+            } else if (str_startswith("-specs=", a)) {
+                rs_trace("%s must be local", a);
+                return EXIT_DISTCC_FAILED;
             } else if (!strcmp(a, "-S")) {
                 seen_opt_s = 1;
             } else if (!strcmp(a, "-fprofile-arcs")
@@ -190,7 +193,7 @@ int dcc_scan_args(char *argv[], char **input_file, char **output_file,
             } else if (!strcmp(a, "-frepo")) {
                 rs_log_info("compiler will emit .rpo files; must be local");
                 return EXIT_DISTCC_FAILED;
-            } else if (str_startswith(a, "-x")) {
+            } else if (str_startswith("-x", a)) {
                 rs_log_info("gcc's -x handling is complex; running locally");
                 return EXIT_DISTCC_FAILED;
             } else if (!strcmp(a, "-c")) {
@@ -237,6 +240,9 @@ int dcc_scan_args(char *argv[], char **input_file, char **output_file,
         return EXIT_DISTCC_FAILED;
     }
 
+    if (dcc_source_needs_local(*input_file))
+        return EXIT_DISTCC_FAILED;
+
     if (!*output_file) {
         /* This is a commandline like "gcc -c hello.c".  They want
          * hello.o, but they don't say so.  For example, the Ethereal
@@ -335,7 +341,8 @@ int dcc_set_output(char **a, char *ofname)
             char *newptr;
 
             if (asprintf(&newptr, "-o%s", ofname) == -1) {
-                rs_fatal("failed to allocate space for output parameter");
+                rs_log_crit("failed to allocate space for output parameter");
+                return EXIT_OUT_OF_MEMORY;
             }
             
             a[i] = newptr;
