@@ -1,9 +1,8 @@
 /* -*- c-file-style: "java"; indent-tabs-mode: nil -*-
  * 
  * distcc -- A simple distributed compiler system
- * $Id: clinet.h,v 1.3 2002/10/07 01:35:19 mbp Exp $ 
  *
- * Copyright (C) 2002 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,4 +20,7 @@
  * USA
  */
 
-int dcc_open_socket_out(const char *host, int port, int *fd);
+int dcc_connect_by_name(const char *host,
+                        int port,
+                        int *p_fd);
+
