@@ -38,17 +38,12 @@
 #include "util.h"
 #include "hosts.h"
 #include "bulk.h"
-#include "strip.h"
 #include "implicit.h"
 #include "exec.h"
 #include "where.h"
 #include "lock.h"
-#include "cpp.h"
-#include "backoff.h"
 #include "timeval.h"
 #include "compile.h"
-#include "state.h"
-#include "arg.h"
 
 
 /**
@@ -75,7 +70,7 @@ static int dcc_compile_local(char *argv[],
     int status;
 
     dcc_note_execution(dcc_hostdef_local, argv);
-    dcc_note_state(DCC_STATE_COMPILE, input_name, "localhost");
+    dcc_note_state(DCC_PHASE_COMPILE, input_name, "localhost");
 
     /* We don't do any redirection of file descriptors when running locally,
      * so if for example cpp is being used in a pipeline we should be fine. */
@@ -112,9 +107,10 @@ static int dcc_compile_local(char *argv[],
  * the compiler itself fails.  If either the compiler or preprocessor fails,
  * @p status is guaranteed to hold a failure value.
  **/
-static int dcc_build_somewhere(char *argv[],
-                               int sg_level,
-                               int *status)
+static int
+dcc_build_somewhere(char *argv[],
+                    int sg_level,
+                    int *status)
 {
     char *input_fname = NULL, *output_fname, *cpp_fname;
     char **argv_stripped;
@@ -136,7 +132,7 @@ static int dcc_build_somewhere(char *argv[],
 
 #if 0
     /* turned off because we never spend long in this state. */
-    dcc_note_state(DCC_STATE_STARTUP, input_fname, NULL);
+    dcc_note_state(DCC_PHASE_STARTUP, input_fname, NULL);
 #endif
 
     if ((ret = dcc_pick_host_from_list(&host, &cpu_lock_fd)) != 0) {
@@ -146,6 +142,8 @@ static int dcc_build_somewhere(char *argv[],
     }
 
     if (host->mode == DCC_MODE_LOCAL)
+        /* We picked localhost and already have a lock on it so no
+         * need to lock it now. */
         goto run_local;
 
     if ((ret = dcc_cpp_maybe(argv, input_fname, &cpp_fname, &cpp_pid) != 0))
@@ -154,6 +152,8 @@ static int dcc_build_somewhere(char *argv[],
     if ((ret = dcc_strip_local_args(argv, &argv_stripped)))
         goto fallback;
 
+    /* FIXME: argv_stripped is leaked. */
+
     if ((ret = dcc_compile_remote(argv_stripped,
                                   input_fname,
                                   cpp_fname,
@@ -168,7 +168,11 @@ static int dcc_build_somewhere(char *argv[],
 
     dcc_unlock(cpu_lock_fd);
 
-    return dcc_critique_status(*status, "compile", input_fname, host, 1);
+    ret = dcc_critique_status(*status, "compile", input_fname, host, 1);
+    if (ret < 128)
+        /* either worked, or remote compile just simply failed,
+         * e.g. with syntax error.  don't bother retrying */
+        return ret;
 
   fallback:
     if (host)
@@ -181,8 +185,10 @@ static int dcc_build_somewhere(char *argv[],
 
     /* "You guys are so lazy!  Do I have to do all the work myself??" */
     if (host) {
-        rs_log_warning("failed to distribute to %s, running locally instead",
-                       host->hostdef_string);
+        rs_log(RS_LOG_WARNING|RS_LOG_NONAME,
+               "failed to distribute %s to %s, running locally instead",
+               input_fname ? input_fname : "(unknown)",
+               host->hostdef_string);
     } else {
         rs_log_warning("failed to distribute, running locally instead");
     }
