@@ -20,7 +20,9 @@
  * USA
  */
 
-int dcc_compile_remote(char **argv, 
+/* remote.c */
+int dcc_compile_remote(char **argv,
+                       char *input_fname,
                        char *cpp_fname,
                        char *output_fname,
                        pid_t cpp_pid,
