@@ -37,13 +37,8 @@
 #include "trace.h"
 #include "exitcode.h"
 #include "util.h"
-#include "strip.h"
 #include "implicit.h"
 #include "exec.h"
-#include "tempfile.h"
-#include "cpp.h"
-#include "filename.h"
-#include "arg.h"
 
 
 /**
@@ -73,7 +68,8 @@ int dcc_cpp_maybe(char **argv, char *input_fname, char **cpp_fname,
         
         /* already preprocessed, great. */
         if (!(*cpp_fname = strdup(input_fname))) {
-            rs_fatal("couldn't duplicate string");
+            rs_log_error("couldn't duplicate string");
+            return EXIT_OUT_OF_MEMORY;
         }
         return 0;
     }
@@ -98,6 +94,8 @@ int dcc_cpp_maybe(char **argv, char *input_fname, char **cpp_fname,
         || (ret = dcc_set_action_opt(cpp_argv, "-E")))
         return ret;
 
+    /* FIXME: cpp_argv is leaked */
+
     return dcc_spawn_child(cpp_argv, cpp_pid,
                            "/dev/null", *cpp_fname, NULL);
 }
