@@ -70,13 +70,10 @@
 #include "exitcode.h"
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "dopt.h"
-#include "setuid.h"
 #include "srvnet.h"
 #include "daemon.h"
-#include "tempfile.h"
 #include "types.h"
 
 
@@ -155,12 +152,22 @@ static int dcc_setup_daemon_path(void)
 int main(int argc, char *argv[])
 {
     int ret;
+    const char *tmp;
 
     dcc_setup_startup_log();
 
     if (distccd_parse_options(argc, (const char **) argv))
         dcc_exit(EXIT_DISTCC_FAILED);
 
+    /* check this before redirecting the logs, so that it's really obvious */
+    if (!dcc_should_be_inetd())
+        if (opt_allowed == NULL) {
+            rs_log_error("--allow option is now mandatory; "
+                         "you must specify which clients are allowed to connect");
+            ret = EXIT_BAD_ARGUMENTS;
+            goto out;
+        }
+
     if ((ret = dcc_set_lifetime()) != 0)
         dcc_exit(ret);
     
@@ -181,10 +188,15 @@ int main(int argc, char *argv[])
     /* Do everything from root directory.  Allows start directory to be
      * unmounted, should make accidental writing of local files cause a
      * failure... */
-    if (chdir("/") == -1) {
-        rs_log_error("failed to chdir to /: %s", strerror(errno));
+    if ((ret = dcc_get_tmp_top(&tmp)))
+        goto out;
+    
+    if (chdir(tmp) == -1) {
+        rs_log_error("failed to chdir to %s: %s", tmp, strerror(errno));
         ret = EXIT_IO_ERROR;
         goto out;
+    } else {
+        rs_trace("chdir to %s", tmp);
     }
 
     if ((ret = dcc_setup_daemon_path()))
