@@ -46,12 +46,9 @@
 #include "util.h"
 #include "hosts.h"
 #include "bulk.h"
-#include "tempfile.h"
 #include "implicit.h"
 #include "compile.h"
-#include "state.h"
-#include "arg.h"
-#include "filename.h"
+
 
 /* Name of this program, for trace.c */
 const char *rs_program_name = "distcc";
@@ -77,7 +74,6 @@ const char *rs_program_name = "distcc";
 static void dcc_show_usage(void)
 {
     dcc_show_version("distcc");
-    dcc_show_copyright();
     printf(
 "Usage:\n"
 "   distcc [COMPILER] [compile options] -o OBJECT -c SOURCE\n"
@@ -204,7 +200,7 @@ int main(int argc, char **argv)
                                           &tweaked_path)) != 0)
             goto out;
         
-        dcc_shallowcopy_argv(argv, &compiler_args, 0);
+        dcc_copy_argv(argv, &compiler_args, 0);
         compiler_args[0] = compiler_name;
     }
 
