@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,11 +21,7 @@
  */
 
 
-/**
- * @file
- *
- * Parse and apply server options.
- **/
+/* dopt.c -- Parse and apply server options. */
 
 #include "config.h"
 
@@ -44,10 +40,9 @@
 #include "types.h"
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "dopt.h"
 #include "exitcode.h"
-#include "setuid.h"
+#include "daemon.h"
 #include "access.h"
 
 int opt_niceness = 5;           /* default */
@@ -88,8 +83,6 @@ int opt_log_stderr = 0;
  */
 int opt_lifetime = 0;
 
-int opt_no_prefork = 0;
-
 const char *arg_pid_file = NULL;
 const char *arg_log_file = NULL;
 
@@ -116,7 +109,6 @@ const struct poptOption options[] = {
     { "no-detach", 0,    POPT_ARG_NONE, &opt_no_detach, 0, 0, 0 },
     { "no-fifo", 0,      POPT_ARG_NONE, &opt_no_fifo, 0, 0, 0 },
     { "no-fork", 0,      POPT_ARG_NONE, &opt_no_fork, 0, 0, 0 },
-    { "no-prefork", 0,   POPT_ARG_NONE, &opt_no_prefork, 0, 0, 0 },
     { "pid-file", 'P',   POPT_ARG_STRING, &arg_pid_file, 0, 0, 0 },
     { "port", 'p',       POPT_ARG_INT, &arg_port,      0, 0, 0 },
     { "user", 0,         POPT_ARG_STRING, &opt_user, 'u', 0, 0 },
@@ -130,7 +122,6 @@ const struct poptOption options[] = {
 static void distccd_show_usage(void)
 {
     dcc_show_version("distccd");
-    dcc_show_copyright();
     printf (
 "Usage:\n"
 "   distccd [OPTIONS]\n"
@@ -185,8 +176,11 @@ int distccd_parse_options(int argc, const char **argv)
             /* TODO: Split this into a small function. */
             struct dcc_allow_list *new;
             new = malloc(sizeof *new);
-            if (!new)
-                rs_fatal("malloc failed");
+            if (!new) {
+                rs_log_crit("malloc failed");
+                exitcode = EXIT_OUT_OF_MEMORY;
+                goto out_exit;
+            }
             new->next = opt_allowed;
             opt_allowed = new;
             if ((exitcode = dcc_parse_mask(poptGetOptArg(po), &new->addr, &new->mask)))
