@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -63,19 +63,15 @@
 #include "exitcode.h"
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "dopt.h"
 #include "exec.h"
-#include "tempfile.h"
 #include "srvnet.h"
 #include "types.h"
 #include "daemon.h"
+#include "netutil.h"
 
-static int dcc_start_server_child(int listen_fd, int accept_fd, struct sockaddr *,
-                                  int);
 static void dcc_nofork_parent(int listen_fd) NORETURN;
-static void dcc_forking_parent(int listen_fd) NORETURN;
 static void dcc_detach(void);
 static void dcc_save_pid(pid_t);
 int dcc_nkids = 0;
@@ -102,6 +98,8 @@ int dcc_standalone_server(void)
     if ((ret = dcc_socket_listen(arg_port, &listen_fd, opt_listen_addr)) != 0)
         return ret;
 
+    dcc_defer_accept(listen_fd);
+    
     set_cloexec_flag(listen_fd, 1);
 
     if (dcc_ncpus(&n_cpus) == 0) 
@@ -140,9 +138,6 @@ int dcc_standalone_server(void)
     if (opt_no_fork) {
         dcc_log_daemon_started("non-forking daemon");   
         dcc_nofork_parent(listen_fd);
-    } else if (opt_no_prefork) {
-        dcc_log_daemon_started("forking daemon");
-        dcc_forking_parent(listen_fd);		/* noreturn */
     } else {
         dcc_log_daemon_started("preforking daemon");
         return dcc_preforking_parent(listen_fd);
@@ -158,12 +153,8 @@ static void dcc_log_child_exited(pid_t kid,
         int sig = WTERMSIG(status);
         int severity = sig == SIGTERM ? RS_LOG_INFO : RS_LOG_ERR;
         
-#ifdef HAVE_STRSIGNAL
-        /* take off every sig! for great justice. */
-        rs_log(severity, "child %d: %s", (int) kid, strsignal(sig));
-#else
-        rs_log_error("child %d: signal %d", (int) kid, sig);
-#endif
+        rs_log(severity, "child %d: signal %d (%s)", (int) kid, sig,
+               WCOREDUMP(status) ? "core dumped" : "no core");
     } else if (WIFEXITED(status)) {
         rs_log_info("child %d exited: exit status %d",
                     (int) kid, WEXITSTATUS(status));
@@ -232,100 +223,27 @@ static void dcc_nofork_parent(int listen_fd)
 {
     while (1) {
         int acc_fd;
-        struct sockaddr cli_addr;
+        struct dcc_sockaddr_storage cli_addr;
         socklen_t cli_len;
 
         rs_log_info("waiting to accept connection");
 
         cli_len = sizeof cli_addr;
-        acc_fd = accept(listen_fd, &cli_addr, &cli_len);
+        acc_fd = accept(listen_fd,
+                        (struct sockaddr *) &cli_addr, &cli_len);
         if (acc_fd == -1 && errno == EINTR) {
             ; 
         }  else if (acc_fd == -1) {
             rs_log_error("accept failed: %s", strerror(errno));
             dcc_exit(EXIT_CONNECT_FAILED);
         } else {
-            dcc_service_job(acc_fd, acc_fd, &cli_addr, cli_len);
-            dcc_cleanup_tempfiles();
+            dcc_service_job(acc_fd, acc_fd, (struct sockaddr *) &cli_addr, cli_len);
+            dcc_close(acc_fd);
         }
     }
 }
 
 
-/**
- * Main loop for the parent process, with the old behaviour of forking as
- * connections are accepted.  Basically it does nothing but wait around to be
- * signalled, or for its children to die.  What a life!
- **/
-static void dcc_forking_parent(int listen_fd)
-{
-    while (1) {
-        struct sockaddr cli_addr;
-        socklen_t cli_len;
-        int acc_fd;
-
-        dcc_reap_kids(FALSE);
-
-        if (dcc_nkids >= dcc_max_kids) {
-            rs_trace("too busy for new connections, waiting for child to complete");
-            dcc_reap_kids(TRUE);
-        }
-
-        rs_log_info("waiting to accept connection");
-
-        cli_len = sizeof cli_addr;
-        acc_fd = accept(listen_fd, &cli_addr, &cli_len);
-        if (acc_fd == -1 && errno == EINTR) {
-            /* just go ahead and check for children */
-        }  else if (acc_fd == -1) {
-            rs_log_error("accept failed: %s", strerror(errno));
-            dcc_exit(EXIT_CONNECT_FAILED);
-        } else {
-            dcc_start_server_child(listen_fd, acc_fd, &cli_addr, cli_len);
-        }
-    }
-}
-
-
-
-
-/**
- * Fork a child to handle an already-accepted incoming connecting.  Not called
- * when in opt_no_fork mode.
- **/
-static int dcc_start_server_child(int listen_fd, int accepted_fd,
-                                  struct sockaddr *cli_addr,
-                                  int cli_len)
-{
-    pid_t kid;
-    int ret, close_ret;
-    
-    kid = fork();
-    if (kid == 0) {
-        dcc_close(listen_fd);
-        ret = dcc_service_job(accepted_fd, accepted_fd, cli_addr, cli_len);
-        close_ret = dcc_close(accepted_fd);
-        dcc_exit(ret ? ret : close_ret);
-        /* doesn't return */
-    } else if (kid == -1) {
-        rs_log_error("fork failed: %s", strerror(errno));
-        return EXIT_OUT_OF_MEMORY; /* probably */
-    } else {
-        /* in parent */
-        ++dcc_nkids;
-        rs_log_info("up to %d children", dcc_nkids);
-
-        if (close(accepted_fd)) {          /* in parent */
-            rs_log_error("failed to close accepted fd%d in parent: %s",
-                         accepted_fd, strerror(errno));
-        }
-    }
-
-    return 0;
-}
-
-
-
 /**
  * Save the pid of the child process into the pid file, if any.
  *
