@@ -60,13 +60,11 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 #include "exec.h"
 #include "lock.h"
 #include "hosts.h"
-#include "arg.h"
 
 static void dcc_inside_child(char **argv,
                              const char *stdin_file,
@@ -76,11 +74,6 @@ static void dcc_inside_child(char **argv,
 
 static void dcc_execvp(char **argv) NORETURN;
 
-/* You can't have core files on Windows. */
-#ifndef WCOREDUMP
-#  define WCOREDUMP(status) 0
-#endif
-
 void dcc_note_execution(struct dcc_hostdef *host, char **argv)
 {
     char *astr;
