@@ -2,7 +2,7 @@
  *
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,7 +33,7 @@
 #include "trace.h"
 #include "util.h"
 #include "exitcode.h"
-#include "filename.h"
+
 
 
 /**
@@ -248,6 +248,23 @@ int dcc_is_object(const char *filename)
 
     return !strcmp(dot, ".o");
 }
+
+
+/* Some files should always be built locally... */
+int
+dcc_source_needs_local(const char *filename)
+{
+    const char *p;
+
+    p = dcc_find_basename(filename);
+
+    if (str_startswith("conftest.", p) || str_startswith("tmp.conftest.", p)) {
+        rs_trace("autoconf tests are run locally: %s", filename);
+        return EXIT_DISTCC_FAILED;
+    }
+
+    return 0;
+}
     
 
 
