@@ -1,9 +1,9 @@
 /* -*- c-file-style: "java"; indent-tabs-mode: nil -*-
  * 
  * distcc -- A simple distributed compiler system
- * $Header: /data/cvs/distcc/src/h_hosts.c,v 1.12 2003/05/26 04:58:07 mbp Exp $ 
+ * $Header: /data/cvs/distcc/src/h_hosts.c,v 1.13 2004/01/30 12:39:14 mbp Exp $ 
  *
- * Copyright (C) 2002 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -67,7 +67,7 @@ int main(int UNUSED(argc), char **argv)
     int nhosts, i;
     int ret;
 
-    rs_add_logger(rs_logger_file, RS_LOG_INFO, NULL, STDERR_FILENO);
+    rs_add_logger(rs_logger_file, RS_LOG_DEBUG, NULL, STDERR_FILENO);
 
     if (argv[1] && !strcmp(argv[1], "-v")) {
         rs_trace_set_level(RS_LOG_DEBUG);
