@@ -1,7 +1,7 @@
 /* -*- c-file-style: "java"; indent-tabs-mode: nil -*- 
  *
  * distcc -- A simple distributed compiler system
- * $Header: /data/cvs/distcc/src/h_scanargs.c,v 1.8 2003/05/04 12:48:11 mbp Exp $ 
+ * $Header: /data/cvs/distcc/src/h_scanargs.c,v 1.9 2003/07/13 08:08:02 mbp Exp $ 
  *
  * Copyright (C) 2002 by Martin Pool <mbp@samba.org>
  *
@@ -34,7 +34,6 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "implicit.h"
 
@@ -51,7 +50,7 @@ int main(int argc, char *argv[])
     char *infname, *outfname;
     char **newargv, **outargv;
 
-    rs_trace_set_level(RS_LOG_WARNING);
+    rs_trace_set_level(RS_LOG_DEBUG);
 
     if (argc < 2) {
 	rs_log_error("usage: h_scanargs COMMAND ARG...\n");
