@@ -1,7 +1,7 @@
 /* -*- c-file-style: "java"; indent-tabs-mode: nil -*- 
  *
  * distcc -- A simple distributed compiler system
- * $Header: /data/cvs/distcc/src/h_strip.c,v 1.3 2003/05/04 12:48:11 mbp Exp $ 
+ * $Header: /data/cvs/distcc/src/h_strip.c,v 1.4 2003/07/13 08:08:02 mbp Exp $ 
  *
  * Copyright (C) 2002 by Martin Pool <mbp@samba.org>
  *
@@ -35,9 +35,7 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
-#include "strip.h"
 
 const char *rs_program_name = __FILE__;
 
