@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,12 +25,6 @@
                      * get along without it.                -- Dilbert
                      */
 
-/**
- * @file
- *
- * Parse and apply server options.
- **/
-
 #include "config.h"
 
 
@@ -57,27 +51,20 @@ int dcc_show_version(const char *prog)
 {
     /* The "built" message is the time this file was built, which may not be
      * completely accurate for the program as a whole unless you do "make
-     * clean" */
+     * clean".
+     *
+     * Message looks like the one from "gcc --version". */
     printf("%s %s %s (protocols 1 and 2) (default port %d)\n"
-           "  built %s %s\n",
+           "  built %s %s\n"
+"Copyright (C) 2002, 2003, 2004 by Martin Pool.\n"
+"Includes miniLZO (C) 1996-2002 by Markus Franz Xaver Johannes Oberhumer.\n"
+"\n"
+"distcc comes with ABSOLUTELY NO WARRANTY.  distcc is free software, and\n"
+"you may use, modify and redistribute it under the terms of the GNU \n"
+"General Public License version 2 or later.\n"
+"\n"
+           ,
            prog, PACKAGE_VERSION, GNU_HOST, DISTCC_DEFAULT_PORT,
            __DATE__, __TIME__);
     return 0;
-}
-
-
-int dcc_show_copyright(void)
-{
-    printf("Copyright (C) 2002, 2003 by Martin Pool\n"
-           "\n"
-"distcc comes with ABSOLUTELY NO WARRANTY.  distcc is free software, and\n"
-"you may use, modify and redistribute it under the terms of the GNU \n"
-"General Public License version 2 or later.  For more information see\n"
-"the file named COPYING or <http://www.fsf.org/>.\n"
-"\n"
-"Please report bugs or features to <distcc@lists.samba.org>.  For more\n"
-"information, see <http://distcc.samba.org/>.\n"
-"\n"
-           );
-    return 0;
 }	
