@@ -35,7 +35,6 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 #include "hosts.h"
@@ -57,7 +56,7 @@ int dcc_parse_hosts_file(const char *fname,
 
     rs_trace("load hosts from %s", fname);
 
-    if ((ret = dcc_load_file(fname, &body)) != 0)
+    if ((ret = dcc_load_file_string(fname, &body)) != 0)
         return ret;
 
     ret = dcc_parse_hosts(body, fname, ret_list, ret_nhosts);
