@@ -96,7 +96,6 @@
 #include "hosts.h"
 #include "exitcode.h"
 #include "snprintf.h"
-#include "tempfile.h"
 
 const int dcc_default_port = DISTCC_DEFAULT_PORT;
 
@@ -242,12 +241,13 @@ static int dcc_parse_ssh_host(struct dcc_hostdef *hostdef,
         return ret;
 
     if (token[0] != '@') {
-        rs_fatal("expected '@' to start ssh token");
+        rs_log_error("expected '@' to start ssh token");
+        return EXIT_BAD_HOSTSPEC;
     }
 
     token++;
 
-    if ((ret = dcc_dup_part(&token, &hostdef->hostname, "/: \t\n\f,")) != 0)
+    if ((ret = dcc_dup_part(&token, &hostdef->hostname, "/: \t\n\r\f,")) != 0)
         return ret;
 
     if (!hostdef->hostname) {
@@ -261,7 +261,7 @@ static int dcc_parse_ssh_host(struct dcc_hostdef *hostdef,
 
     if (token[0] == ':') {
         token++;
-        if ((ret = dcc_dup_part(&token, &hostdef->ssh_command, " \t\n\f,")))
+        if ((ret = dcc_dup_part(&token, &hostdef->ssh_command, " \t\n\r\f,")))
             return ret;
     }
     
@@ -279,7 +279,7 @@ static int dcc_parse_tcp_host(struct dcc_hostdef *hostdef,
     int ret;
     const char *token = token_start;
     
-    if ((ret = dcc_dup_part(&token, &hostdef->hostname, "/: \t\n\f,")))
+    if ((ret = dcc_dup_part(&token, &hostdef->hostname, "/: \t\n\r\f,")))
         return ret;
 
     if (!hostdef->hostname) {
@@ -378,7 +378,7 @@ int dcc_parse_hosts(const char *where, const char *source_name,
         if (where[0] == '#') {
             do
                 where++;
-            while (where[0] != '\n' && where[0] != '\0');
+            while (where[0] != '\n' && where[0] != '\r' && where[0] != '\0');
             continue;
         }
 
@@ -388,7 +388,7 @@ int dcc_parse_hosts(const char *where, const char *source_name,
         }
 
         token_start = where;
-        token_len = strcspn(where, " #\t\n\f");
+        token_len = strcspn(where, " #\t\n\f\r");
 
         /* Allocate new list item */
         curr = calloc(1, sizeof(struct dcc_hostdef));
@@ -398,7 +398,7 @@ int dcc_parse_hosts(const char *where, const char *source_name,
         }
 
         /* Store verbatim hostname */
-        if (!(curr->hostdef_string = strndup(token_start, token_len))) {
+        if (!(curr->hostdef_string = strndup(token_start, (size_t) token_len))) {
             rs_log_crit("failed to allocate hostdef_string");
             return EXIT_OUT_OF_MEMORY;
         }
@@ -417,7 +417,7 @@ int dcc_parse_hosts(const char *where, const char *source_name,
         curr->protover = DCC_VER_1; /* default */
         curr->compr = DCC_COMPRESS_NONE;
             
-        has_at = (memchr(token_start, '@', token_len) != NULL);
+        has_at = (memchr(token_start, '@', (size_t) token_len) != NULL);
 
         if (!strncmp(token_start, "localhost", 9)
             && (token_len == 9 || token_start[9] == '/')) {
