@@ -47,6 +47,11 @@ struct dcc_hostdef {
      * definition. **/
     char * hostdef_string;
 
+    enum dcc_protover protover;
+
+    /** The kind of compression to use for this host */
+    enum dcc_compress compr;
+
     struct dcc_hostdef *next;
 };
 
