@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -56,32 +56,16 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 
 
 
-const int dcc_connect_timeout = 15; /* seconds */
-
 /** Timeout for all IO other than opening connections.  Much longer, because
  * compiling files can take a long time. **/
 const int dcc_io_timeout = 300; /* seconds */
 
 
-
-int dcc_want_mmap(void)
-{
-#if defined(HAVE_MMAP) && !defined(__hpux)
-    /* mmap is dangerous for our purposes on HPUX because it's not consistent
-     * with regular IO */
-    return dcc_getenv_bool("DISTCC_MMAP", 1);
-#else
-    return 0;
-#endif
-}
-
-
 /**
  * @todo Perhaps only apply the timeout for initial connections, not when
  * doing regular IO.
@@ -118,7 +102,8 @@ int dcc_select_for_read(int fd,
             rs_log_error("IO timeout");
             return EXIT_IO_ERROR;
         } else if (!FD_ISSET(fd, &fds)) {
-            rs_fatal("how did fd not get set?");
+            rs_log_error("how did fd not get set?");
+            continue;
         } else {
             break;              /* woot */
         }
