@@ -1,4 +1,4 @@
-/* -*- c-file-style: "gnu"; indent-tabs-mode: nil; -*-
+/* -*- c-file-style: "k&r"; c-basic-offset: 4; indent-tabs-mode: nil; -*-
  * 
  * distcc -- A simple distributed compiler system
  *
@@ -20,18 +20,18 @@
  * USA
  */
 
-/**
+/*
  * @file
  *
  * Gnome 2.x monitor for distcc.
- **/
-
-/**
- * We remember the past states of each slot in a GQueue, which is
- * stored in the "history" column of the TreeMode for that slot.  The
- * Queue directly contains the state values.  The renderer knows how
- * to walk over the queue and draw state rectangles for the values it
- * finds.
+ *
+ * For each slot we have a record in a tree model, including an array
+ * indicating the past states.  This is stored in the "history" column
+ * of the TreeMode for that slot.
+ *
+ * The renderer knows how to walk over the queue and draw state
+ * rectangles for the values it finds.  The queue is implemented as a
+ * circular array, whose values are initialized to idle.
  *
  * Starved jobs are currently not shown in the chart view.
  *
@@ -69,10 +69,8 @@
 #include "types.h"
 #include "distcc.h"
 #include "rpc.h"
-#include "io.h"
 #include "trace.h"
 #include "exitcode.h"
-#include "state.h"
 #include "mon.h"
 #include "renderer.h"
 
@@ -87,9 +85,6 @@ static GtkWidget *chart_treeview;
 static GtkListStore *chart_model;
 
 
-/** Number of previous states to retain for drawing history. */
-const guint dcc_max_history_queue = 100;
-
 
 /* Note: these must match the types given in order in the call to
    gtk_list_store_new() */
@@ -106,20 +101,20 @@ enum {
  * Graphics contexts to be used to draw each particular state into the
  * model.
  **/
-GdkGC *dcc_state_gc[DCC_STATE_DONE];
+GdkGC *dcc_phase_gc[DCC_PHASE_DONE];
 
 
 #if 0
 /* shades of red */
 const GdkColor task_color[] = {
-  { 0, 0x2222, 0, 0 },          /* DCC_STATE_STARTUP, */
-  { 0, 0x4444, 0, 0 },          /* DCC_STATE_BLOCKED, */
-  { 0, 0x6666, 0, 0 },          /* DCC_STATE_CONNECT, */
-  { 0, 0x8888, 0, 0 },          /* DCC_STATE_CPP, */
-  { 0, 0xaaaa, 0, 0 },          /* DCC_STATE_SEND, */
-  { 0, 0xcccc, 0, 0 },          /* DCC_STATE_COMPILE, */
-  { 0, 0xeeee, 0, 0 },          /* DCC_STATE_RECEIVE, */
-  { 0, 0xffff, 0xffff, 0 },     /* DCC_STATE_DONE */
+  { 0, 0x2222, 0, 0 },          /* DCC_PHASE_STARTUP, */
+  { 0, 0x4444, 0, 0 },          /* DCC_PHASE_BLOCKED, */
+  { 0, 0x6666, 0, 0 },          /* DCC_PHASE_CONNECT, */
+  { 0, 0x8888, 0, 0 },          /* DCC_PHASE_CPP, */
+  { 0, 0xaaaa, 0, 0 },          /* DCC_PHASE_SEND, */
+  { 0, 0xcccc, 0, 0 },          /* DCC_PHASE_COMPILE, */
+  { 0, 0xeeee, 0, 0 },          /* DCC_PHASE_RECEIVE, */
+  { 0, 0xffff, 0xffff, 0 },     /* DCC_PHASE_DONE */
 };
 #endif
 
@@ -130,14 +125,14 @@ const GdkColor task_color[] = {
  * These color names are from the GNOME standard palette.
  */
 const GdkColor task_color[] = {
-  { 0, 0x9999, 0, 0 },          /* DCC_STATE_STARTUP, accent red dark */
-  { 0, 0x9999, 0, 0 },          /* DCC_STATE_BLOCKED, accent red dark */
-  { 0, 0xc1c1, 0x6666, 0x5a5a }, /* DCC_STATE_CONNECT, red medium  */
-  { 0, 0x8888, 0x7f7f, 0xa3a3 }, /* DCC_STATE_CPP, purple medium*/
-  { 0, 0xe0e0, 0xc3c3, 0x9e9e }, /* DCC_STATE_SEND, face skin medium*/
-  { 0, 0x8383, 0xa6a6, 0x7f7f }, /* DCC_STATE_COMPILE, green medium */
-  { 0, 0x7575, 0x9090, 0xaeae }, /* DCC_STATE_RECEIVE, blue medium*/
-  { 0, 0, 0, 0 },               /* DCC_STATE_DONE */
+  { 0, 0x9999, 0, 0 },          /* DCC_PHASE_STARTUP, accent red dark */
+  { 0, 0x9999, 0, 0 },          /* DCC_PHASE_BLOCKED, accent red dark */
+  { 0, 0xc1c1, 0x6666, 0x5a5a }, /* DCC_PHASE_CONNECT, red medium  */
+  { 0, 0x8888, 0x7f7f, 0xa3a3 }, /* DCC_PHASE_CPP, purple medium*/
+  { 0, 0xe0e0, 0xc3c3, 0x9e9e }, /* DCC_PHASE_SEND, face skin medium*/
+  { 0, 0x8383, 0xa6a6, 0x7f7f }, /* DCC_PHASE_COMPILE, green medium */
+  { 0, 0x7575, 0x9090, 0xaeae }, /* DCC_PHASE_RECEIVE, blue medium*/
+  { 0, 0, 0, 0 },               /* DCC_PHASE_DONE */
 };
 
 
@@ -155,35 +150,22 @@ dcc_setup_tree_model (void)
 }
 
 
-static void
-dcc_history_push (GQueue *history_queue,
-                  enum dcc_state new_state)
-{
-  g_queue_push_head (history_queue, GINT_TO_POINTER (new_state));
-}
-
-
-
 static void
 dcc_row_history_push (GtkListStore *model,
                       GtkTreeIter *tree_iter,
-                      enum dcc_state new_state)
+                      enum dcc_phase new_state)
 {
-  GQueue *history_queue;
+     struct dcc_history *history;
 
-  gtk_tree_model_get (GTK_TREE_MODEL (model), tree_iter,
-                      COLUMN_HISTORY, &history_queue,
-                      -1);
+     gtk_tree_model_get(GTK_TREE_MODEL (model), tree_iter,
+                        COLUMN_HISTORY, &history,
+                        -1);
 
-  dcc_history_push (history_queue, new_state);
+     dcc_history_push(history, new_state);
 
-  /* Now trim it back down.  200 entries should be enough... */
-  while (history_queue->length > dcc_max_history_queue)
-    g_queue_pop_tail (history_queue);
-
-  /* Perhaps we should call gtk_tree_model_row_changed(), but at the
-     moment every call to this is associated with some other change to
-     the model so I don't think there's any need. */
+     /* Perhaps we should call gtk_tree_model_row_changed(), but at the
+        moment every call to this is associated with some other change to
+        the model so I don't think there's any need. */
 }
 
 
@@ -191,15 +173,15 @@ dcc_row_history_push (GtkListStore *model,
 static void
 dcc_set_row_from_task (GtkListStore *model,
                          GtkTreeIter *tree_iter,
-                         struct dcc_history *task)
+                         struct dcc_task_state *task)
 {
-  dcc_row_history_push (model, tree_iter, task->curr_state);
+  dcc_row_history_push (model, tree_iter, task->curr_phase);
 
   gtk_list_store_set (model, tree_iter,
                       COLUMN_HOST, task->host,
                       COLUMN_SLOT, task->slot, 
                       COLUMN_FILE, task->file,
-                      COLUMN_STATE, dcc_get_state_name(task->curr_state),
+                      COLUMN_STATE, dcc_get_phase_name(task->curr_phase),
                       -1);
 }
 
@@ -208,35 +190,52 @@ static void
 dcc_insert_row_from_task (GtkListStore *model,
                           GtkTreeIter *tree_iter,
                           GtkTreeIter *insert_before,
-                          struct dcc_history *task_iter)
+                          struct dcc_task_state *task_iter)
 {
-  GQueue *history_queue;
+     struct dcc_history *history;
 
-  history_queue = g_queue_new();
+     history = dcc_history_new();
 
-  dcc_history_push (history_queue, task_iter->curr_state);
+     dcc_history_push(history, task_iter->curr_phase);
   
-  gtk_list_store_insert_before (chart_model, tree_iter, insert_before);
-  gtk_list_store_set (model, tree_iter,
-                      COLUMN_HOST, task_iter->host,
-                      COLUMN_SLOT, task_iter->slot, 
-                      COLUMN_FILE, task_iter->file,
-                      COLUMN_STATE, dcc_get_state_name(task_iter->curr_state),
-                      COLUMN_HISTORY, history_queue,
-                      -1);
+     gtk_list_store_insert_before(chart_model, tree_iter, insert_before);
+     
+     gtk_list_store_set(model, tree_iter,
+                        COLUMN_HOST, task_iter->host,
+                        COLUMN_SLOT, task_iter->slot, 
+                        COLUMN_FILE, task_iter->file,
+                        COLUMN_STATE, dcc_get_phase_name(task_iter->curr_phase),
+                        COLUMN_HISTORY, history,
+                        -1);
 }
 
 
 static void
-dcc_set_row_idle (GtkListStore *model,
-                  GtkTreeIter *tree_iter)
+dcc_set_row_idle(GtkListStore *model,
+                 GtkTreeIter *tree_iter)
 {
-  dcc_row_history_push (model, tree_iter, DCC_STATE_DONE);
-  
-  gtk_list_store_set (model, tree_iter,
-                      COLUMN_FILE, NULL,
-                      COLUMN_STATE, NULL, 
-                      -1);
+     struct dcc_history *history;
+
+     gtk_tree_model_get(GTK_TREE_MODEL (model), tree_iter,
+                        COLUMN_HISTORY, &history,
+                        -1);
+
+     /* only write to the treemodel if it was previously non-idle */
+     if (history->past_phases[history->now] != DCC_PHASE_DONE) {
+          gtk_list_store_set (model, tree_iter,
+                              COLUMN_FILE, NULL,
+                              COLUMN_STATE, NULL, 
+                              -1);
+     } else {
+          /* it still changed... */
+          GtkTreePath *path;
+
+          path = gtk_tree_model_get_path(GTK_TREE_MODEL(model), tree_iter);
+          gtk_tree_model_row_changed(GTK_TREE_MODEL(model), path, tree_iter);
+          gtk_tree_path_free(path);
+     }
+     
+     dcc_history_push(history, DCC_PHASE_DONE);
 }
 
 
@@ -267,14 +266,12 @@ dcc_set_row_idle (GtkListStore *model,
  * every state history.
  **/
 static void
-dcc_update_store_from_tasks (struct dcc_history *task_list)
+dcc_update_store_from_tasks (struct dcc_task_state *task_list)
 {
-  struct dcc_history *task_iter;
+  struct dcc_task_state *task_iter;
   GtkTreeIter tree_iter[1];
   gboolean tree_valid;
   int cmp;
-  gchar *row_host;
-  int row_slot;
   GtkTreeModel *tree_model = GTK_TREE_MODEL (chart_model);
 
   tree_valid = gtk_tree_model_get_iter_first (tree_model, tree_iter);
@@ -283,7 +280,10 @@ dcc_update_store_from_tasks (struct dcc_history *task_list)
        task_iter != NULL && tree_valid;
        )
     {
-      if (task_iter->curr_state == DCC_STATE_DONE
+      gchar *row_host;
+      int row_slot;
+      
+      if (task_iter->curr_phase == DCC_PHASE_DONE
           || task_iter->host[0] == '\0'
           || task_iter->file[0] == '\0')
         {
@@ -346,7 +346,7 @@ dcc_update_store_from_tasks (struct dcc_history *task_list)
        task_iter != NULL;
        task_iter = task_iter->next)
     {
-      if (task_iter->curr_state == DCC_STATE_DONE)
+      if (task_iter->curr_phase == DCC_PHASE_DONE)
         continue;
       if (task_iter->host[0] == '\0'
           || task_iter->file[0] == '\0')
@@ -380,7 +380,7 @@ dcc_update_store_from_tasks (struct dcc_history *task_list)
  **/
 static gint dcc_gnome_update_cb (gpointer UNUSED(view_void))
 {
-  struct dcc_history *task_list;
+  struct dcc_task_state *task_list;
   
   if (dcc_mon_poll (&task_list))
     {
@@ -390,7 +390,7 @@ static gint dcc_gnome_update_cb (gpointer UNUSED(view_void))
 
   dcc_update_store_from_tasks (task_list);
 
-  dcc_history_free (task_list);
+  dcc_task_state_free (task_list);
   
   return TRUE;                  /* please call again */
 }
@@ -420,10 +420,11 @@ static gchar *dcc_gnome_get_title (void)
 }
 
 
-static gint dcc_gnome_load_update_cb (gpointer label_void)
+static gint dcc_gnome_load_update_cb (gpointer data)
 {
   gchar message[200];
   double loadavg[3];
+  guint context_id;
 
   if (getloadavg (loadavg, 3) == -1)
     {
@@ -435,8 +436,10 @@ static gint dcc_gnome_load_update_cb (gpointer label_void)
             "Load average: %.2f, %.2f, %.2f",
             loadavg[0], loadavg[1], loadavg[2]);
 
-  gtk_label_set_text (GTK_LABEL (label_void),
-                      message);
+  context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR (data), "load");
+
+  gtk_statusbar_pop(GTK_STATUSBAR (data), context_id);
+  gtk_statusbar_push(GTK_STATUSBAR (data), context_id, message);
 
   return TRUE;                  /* please call again */
 }
@@ -449,12 +452,12 @@ static gint dcc_gnome_load_update_cb (gpointer label_void)
 static void
 dcc_create_state_gcs (GtkWidget *widget)
 {
-  enum dcc_state i_state;
+  enum dcc_phase i_state;
   
-  for (i_state = 0; i_state < DCC_STATE_DONE; i_state++)
+  for (i_state = 0; i_state < DCC_PHASE_DONE; i_state++)
     {
-      dcc_state_gc[i_state] = gdk_gc_new (widget->window);
-      gdk_gc_set_rgb_fg_color (dcc_state_gc[i_state],
+      dcc_phase_gc[i_state] = gdk_gc_new (widget->window);
+      gdk_gc_set_rgb_fg_color (dcc_phase_gc[i_state],
                                (GdkColor *) &task_color[i_state]);
 
     }
@@ -542,7 +545,7 @@ static void dcc_gnome_make_proc_view (GtkTreeModel *proc_model,
   gtk_container_add (GTK_CONTAINER (proc_scroll), chart_treeview);
 
   /* Expands to fill all space */
-  align = gtk_alignment_new (0, 0, 1, 1);
+  align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
   gtk_container_add (GTK_CONTAINER (align), proc_scroll);
 
   *align_return = align;
@@ -551,11 +554,13 @@ static void dcc_gnome_make_proc_view (GtkTreeModel *proc_model,
 
 static GtkWidget * dcc_gnome_make_load_bar (void)
 {
-  GtkWidget *bar, *box;
+  GtkWidget *bar;
+  gint context_id;
 
-  bar = gtk_label_new ("Load: ");
-  box = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (box), bar, FALSE, FALSE, 6);
+  bar = gtk_statusbar_new ();
+  context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR (bar), "load");
+
+  gtk_statusbar_push(GTK_STATUSBAR (bar), context_id, "Load: ");
 
   g_timeout_add (2000,          /* ms */
                  dcc_gnome_load_update_cb,
@@ -563,7 +568,7 @@ static GtkWidget * dcc_gnome_make_load_bar (void)
 
   dcc_gnome_load_update_cb (bar);
 
-  return box;
+  return bar;
 }
 
 
@@ -573,8 +578,14 @@ static GtkWidget * dcc_gnome_make_mainwin (void)
 
   mainwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  gtk_window_set_title (GTK_WINDOW (mainwin),
-                        dcc_gnome_get_title());
+  {
+    char *title;
+    title = dcc_gnome_get_title ();
+
+    gtk_window_set_title (GTK_WINDOW (mainwin),
+                          title);
+    free (title);
+  }
   
   /* Set a reasonable default size that allows all columns and a few
      rows to be seen with a typical theme */
@@ -617,17 +628,12 @@ static int dcc_gnome_make_app (void)
   gtk_container_add (GTK_CONTAINER (topbox),
                      proc_align);
 
-  /* Standard gnome padding is 12px */
-
   gtk_box_pack_end (GTK_BOX (topbox),
                     load_bar,
                     FALSE, /* expand */
                     FALSE,
-                    6);
+                    0);
     
-  gtk_window_set_title (GTK_WINDOW (mainwin),
-                        dcc_gnome_get_title ());
-
   g_timeout_add_full (G_PRIORITY_HIGH_IDLE,
                       500, /* ms */
                       dcc_gnome_update_cb,
