@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,10 +22,6 @@
 
 #include "config.h"
 
-#ifdef HAVE_STDINT_H
-#  include <stdint.h>
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -36,12 +32,8 @@
 #include "types.h"
 #include "distcc.h"
 #include "rpc.h"
-#include "io.h"
 #include "trace.h"
 #include "exitcode.h"
-#include "state.h"
-#include "tempfile.h"
-#include "filename.h"
 #include "snprintf.h"
 #include "mon.h"
 
@@ -69,7 +61,7 @@ static void usage(void)
 
 int main(int argc, char *argv[])
 {
-    struct dcc_mon_list *list;
+    struct dcc_task_state *list;
     int ret;
     float delay;
     char *end;
@@ -94,19 +86,29 @@ int main(int argc, char *argv[])
     setvbuf (stdout, NULL, _IOLBF, BUFSIZ);
 
     do {
+        struct dcc_task_state *i;
+        
         if ((ret = dcc_mon_poll(&list)))
             return ret;
 
-        for (; list; list = list->next) {
+        for (i = list; i; i = i->next) {
+#if 1
+            if (i->curr_phase == DCC_PHASE_DONE)
+                continue;
+#endif
             /* Assume 80 cols = */
-            printf("%6d  %-10.10s  %-30.30s %28.28s\n",
-                   list->cpid, list->state, list->file, list->host);
+            printf("%6ld  %-10.10s  %-30.30s %24.24s[%d]\n",
+                   (long) i->cpid,
+                   dcc_get_phase_name(i->curr_phase),
+                   i->file, i->host, i->slot);
         }
 
         printf("\n");
 
         /* XXX: usleep() is probably not very portable */
         usleep(delay * 1000000);
+        
+        dcc_task_state_free(list);
     } while (delay);
     
     return 0;
