@@ -58,7 +58,7 @@ int dcc_ncpus(int *ncpus)
         return 0;
     } else {
         rs_log_error("pstat_getdynamic failed: %s", strerror(errno));
-        *ncpus = -1;
+        *ncpus = 1;
         return EXIT_DISTCC_FAILED;
     }
 }
@@ -90,7 +90,7 @@ char_varying(66) module_name;
      return 0;
 }
 
-#elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__)
+#elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__bsdi__)
 
 /* http://www.FreeBSD.org/cgi/man.cgi?query=sysctl&sektion=3&manpath=FreeBSD+4.6-stable
    http://www.openbsd.org/cgi-bin/man.cgi?query=sysctl&sektion=3&manpath=OpenBSD+Current
@@ -111,6 +111,7 @@ int dcc_ncpus(int *ncpus)
     else {
         rs_log_error("sysctl(CTL_HW:HW_NCPU) failed: %s",
                      strerror(errno));
+        *ncpus = 1;
         return EXIT_DISTCC_FAILED;
     }
 }
@@ -140,6 +141,7 @@ int dcc_ncpus(int *ncpus)
     if (*ncpus == -1) {
         rs_log_error("sysconf(_SC_NPROCESSORS_ONLN) failed: %s",
                      strerror(errno));
+        *ncpus = 1;
         return EXIT_DISTCC_FAILED;
     } else if (*ncpus == 0) {
 	/* if there are no cpus, what are we running on?  But it has
