@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2003, 2004 by Martin Pool
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +21,9 @@
  */
 
 
+/* pump.c - Transfer of bulk data (source, object code) */
+
+
 #include "config.h"
 
 #include <stdio.h>
@@ -46,104 +49,13 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 
 
-/**
- * @file
- * Transfer of bulk data (source, object code)
- **/
-
-
-/**
- * Receive data from the network to the filesystem.  Uses mmap if the data is
- * large and we can, otherwise reads into a mallocd buffer and writes it out.
- *
- * @p out_fd should be open read/write.
- **/
-static int dcc_r_bulk_plain(int out_fd,
-                            int in_fd,
-                            unsigned len)
-{
-    int ret;
-    char *buf = NULL;
-    int is_mmapped = 0;
-
-    if (len == 0)
-        return 0;               /* just check */
-
-    if (len >= 65536) {
-#ifdef HAVE_MMAP
-        /* First truncate the file, so that we have space to write to it.  This
-         * will fail if we're e.g. writing to stdout. */
-    
-        buf = mmap(NULL,            /* suggested address */
-                   len, PROT_WRITE|PROT_READ,
-                   MAP_SHARED, out_fd,
-                   0);              /* offset */
-    
-        if (buf == MAP_FAILED) {
-            rs_trace("mmap output fd%d failed: %s", out_fd, strerror(errno));
-        } else {
-            is_mmapped = 1;
-
-            rs_trace("receive %d bytes using mmap", len);
-
-            /* Now make it big enough to write to.  You fall through the floor if
-             * you try to write to nonexistent parts of the file.
-             *
-             * Because this routine is for uncompressed data we know ahead of
-             * time exactly how much space we will need.
-             */
-            if (ftruncate(out_fd, len) == -1) {
-                rs_log_error("ftruncate fd%d failed: %s", out_fd,
-                             strerror(errno));
-                ret = EXIT_IO_ERROR;
-                goto out;
-            }
-        }
-#endif
-    }
-
-    if (!is_mmapped) {
-        if ((buf = malloc(len)) == NULL) {
-            rs_log_error("failed to allocate receipt buffer");
-            ret = EXIT_OUT_OF_MEMORY;
-            goto out;
-        }
-    }
-
-    if ((ret = dcc_readx(in_fd, buf, len)) != 0)
-        goto out;
-
-    if (!is_mmapped) {
-        ret = dcc_writex(out_fd, buf, len);
-    }
-
-out:
-    if (is_mmapped) {
-        if (munmap(buf, len) == -1) {
-            rs_log_error("munmap (output) failed: %s",
-                         strerror(errno));
-            ret = ret ? ret : EXIT_IO_ERROR;
-        }
-    } else { 
-        free(buf);
-    }
-    
-    return ret;
-}
-
-
-/**
- * Common routine for reading a file body used by both fifos and
- * regular files.
- *
- * The output file descriptor is not closed, because this routine is
- * also used for copying onto stderr.
- **/
+/*
+ * Receive either compressed or uncompressed bulk data.
+ */
 int dcc_r_bulk(int ofd,
                int ifd,
                unsigned f_size,
@@ -153,11 +65,12 @@ int dcc_r_bulk(int ofd,
         return 0;               /* don't decompress nothing */
     
     if (compression == DCC_COMPRESS_NONE) {
-        return dcc_r_bulk_plain(ofd, ifd, f_size);
+        return dcc_pump_readwrite(ofd, ifd, f_size);
     } else if (compression == DCC_COMPRESS_LZO1X) {
         return dcc_r_bulk_lzo1x(ofd, ifd, f_size);
     } else {
-        rs_fatal("impossible compression %d", compression);
+        rs_log_error("impossible compression %d", compression);
+        return EXIT_PROTOCOL_ERROR;
     }    
 }
 
@@ -181,7 +94,8 @@ int dcc_r_bulk(int ofd,
  * This would require some approximation to a circular buffer though, which
  * might be more complex.
  **/
-int dcc_pump_readwrite(int ofd, int ifd, size_t n)
+int
+dcc_pump_readwrite(int ofd, int ifd, size_t n)
 {
     static char buf[262144];    /* we're not recursive */
     char *p;
