@@ -41,7 +41,6 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "exitcode.h"
 #include "rpc.h"
 #include "snprintf.h"
@@ -73,7 +72,8 @@ int dcc_x_token_int(int ofd, const char *token, unsigned param)
     const char *hex = "0123456789abcdef";
 
     if (strlen(token) != 4) {
-        rs_fatal("token \"%s\" seems wrong", token);
+        rs_log_crit("token \"%s\" seems wrong", token);
+        return EXIT_PROTOCOL_ERROR;
     }
     memcpy(buf, token, 4);
 
@@ -167,7 +167,8 @@ int dcc_r_token_int(int ifd, const char *expected, unsigned *val)
     int ret;
     
     if (strlen(expected) != 4) {
-        rs_fatal("expected token \"%s\" seems wrong", expected);
+        rs_log_error("expected token \"%s\" seems wrong", expected);
+        return EXIT_PROTOCOL_ERROR;
     }
 
     if ((ret = dcc_readx(ifd, buf, 12))) {
@@ -202,12 +203,17 @@ int dcc_r_token_int(int ifd, const char *expected, unsigned *val)
 /**
  * Read a byte string of length @p l into a newly allocated buffer, returned in @p buf.
  **/
-int dcc_r_str_alloc(int fd, int l, char **buf)
+int dcc_r_str_alloc(int fd, unsigned l, char **buf)
 {
      char *s;
 
-     if (l < 0)
-         rs_fatal("oops, l < 0");
+#if 0
+     /* never true  */
+     if (l < 0) {
+         rs_log_crit("oops, l < 0");
+         return EXIT_PROTOCOL_ERROR;
+     }
+#endif
 
 /*      rs_trace("read %d byte string", l); */
 
