@@ -26,8 +26,8 @@
 int dcc_x_result_header(int ofd, enum dcc_protover);
 int dcc_r_result_header(int ofd, enum dcc_protover);
 
-int dcc_x_cc_status(int, unsigned);
-int dcc_r_cc_status(int, unsigned *);
+int dcc_x_cc_status(int, int);
+int dcc_r_cc_status(int, int *);
 
 int dcc_x_token_int(int ofd, const char *token, unsigned param);
 int dcc_r_token_int(int ifd, const char *expected, unsigned int *val);
