@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -46,7 +46,6 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 
@@ -150,17 +149,16 @@ static ssize_t sys_sendfile(int ofd, int ifd, off_t *offset, size_t size)
 #endif /* !(__FreeBSD__) && !def(linux) */
 
 
-/**
+/*
  * Transmit the body of a file using sendfile().
  *
- * If the sendfile() call fails in a way that makes us think that
- * regular IO might work, then we try that instead.  For example, the
- * /tmp filesystem may not support sendfile().
- *
- * @param ofd Output fd
- * @param ifd Input file (must allow mmap)
- **/
-int dcc_pump_sendfile(int ofd, int ifd, size_t size)
+ * Linux at the moment requires the input be page-based -- ie a disk file, and
+ * only on particular filesystems.  If the sendfile() call fails in a way that
+ * makes us think that regular IO might work, then we try that instead.  For
+ * example, the /tmp filesystem may not support sendfile().
+ */
+int
+dcc_pump_sendfile(int ofd, int ifd, size_t size)
 {
     ssize_t sent;
     off_t offset = 0;
