@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -69,22 +69,20 @@
 #  include <sys/signal.h>
 #endif /* HAVE_SYS_SIGNAL_H */
 #include <sys/param.h>
+#include <sys/socket.h>
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "rpc.h"
 #include "exitcode.h"
+#include "snprintf.h"
 #include "dopt.h"
-#include "tempfile.h"
 #include "bulk.h"
 #include "exec.h"
 #include "srvnet.h"
-#include "filename.h"
 #include "hosts.h"
 #include "daemon.h"
-#include "arg.h"
 
 
 /**
@@ -103,7 +101,8 @@ static int dcc_run_job(int in_fd, int out_fd);
 static int dcc_add_log_to_file(const char *err_fname)
 {
     if (dcc_compile_log_fd != -1) {
-        rs_fatal("compile log already open?");
+        rs_log_crit("compile log already open?");
+        return 0;               /* continue? */
     }
     
     dcc_compile_log_fd = open(err_fname, O_WRONLY|O_CREAT|O_TRUNC, 0600);
@@ -123,7 +122,8 @@ static int dcc_add_log_to_file(const char *err_fname)
 static int dcc_remove_log_to_file(void)
 {
     if (dcc_compile_log_fd == -1) {
-        rs_fatal("compile log not open?");
+        rs_log_warning("compile log not open?");
+        return 0;               /* continue? */
     }
 
     /* must exactly match call in dcc_add_log_to_file */
@@ -139,11 +139,10 @@ static int dcc_remove_log_to_file(void)
 
 
 
-/**
- * Read and execute a job to/from socket @p ifd
- *
- * @return standard exit code
- **/
+/* Read and execute a job to/from socket.  This is the common entry point no
+ * matter what mode the daemon is running in: preforked, nonforked, or
+ * ssh/inetd.
+ */
 int dcc_service_job(int in_fd,
                     int out_fd,
                     struct sockaddr *cli_addr,
@@ -152,11 +151,15 @@ int dcc_service_job(int in_fd,
     int ret;
 
     /* Log client name and check access if appropriate.  For ssh connections
-     * the client comes from a localhost socket. */
-    if ((ret = dcc_check_client(cli_addr, cli_len)) != 0)
-        return ret;
+     * the client comes from a unix-domain socket and that's always
+     * allowed. */
+    if ((ret = dcc_check_client(cli_addr, cli_len, opt_allowed)) != 0)
+        goto out;
 
-    return dcc_run_job(in_fd, out_fd);
+    ret = dcc_run_job(in_fd, out_fd);
+
+out:
+    return ret;
 }
 
 
@@ -190,7 +193,7 @@ static int dcc_input_tmpnam(char * orig_input,
  **/
 static int dcc_check_compiler_masq(char *compiler_name)
 {
-    const char *envpath, *newpath, *p, *n;
+    const char *envpath, *p, *n;
     char *buf = NULL;
     struct stat sb;
     int len;
@@ -204,7 +207,7 @@ static int dcc_check_compiler_masq(char *compiler_name)
         return 0;
     }
 
-    for (n = p = envpath, newpath = NULL; *n; p = n) {
+    for (n = p = envpath; *n; p = n) {
         n = strchr(p, ':');
         if (n)
             len = n++ - p;
@@ -250,7 +253,7 @@ static int dcc_run_job(int in_fd,
                        int out_fd)
 {
     char **argv;
-    unsigned status;
+    int status;
     char *temp_i, *temp_o, *err_fname, *out_fname;
     int ret, compile_ret;
     char *orig_input, *orig_output;
@@ -259,9 +262,9 @@ static int dcc_run_job(int in_fd,
     enum dcc_compress compr;
     
     if ((ret = dcc_make_tmpnam("distcc", ".stderr", &err_fname)))
-        return ret;
+        goto out_cleanup;
     if ((ret = dcc_make_tmpnam("distcc", ".stdout", &out_fname)))
-        return ret;
+        goto out_cleanup;
     
     dcc_remove_if_exists(err_fname);
     dcc_remove_if_exists(out_fname);
@@ -300,7 +303,7 @@ static int dcc_run_job(int in_fd,
 
     if ((ret = dcc_check_compiler_masq(argv[0])))
         goto out_cleanup;
-    
+
     if ((compile_ret = dcc_spawn_child(argv, &cc_pid,
                                        "/dev/null", out_fname, err_fname))
         || (compile_ret = dcc_collect_child("cc", cc_pid, &status))) {
@@ -310,17 +313,17 @@ static int dcc_run_job(int in_fd,
     
     if ((ret = dcc_x_result_header(out_fd, protover))
         || (ret = dcc_x_cc_status(out_fd, status))
-        || (ret = dcc_x_file(out_fd, err_fname, "SERR", compr))
-        || (ret = dcc_x_file(out_fd, out_fname, "SOUT", compr))
+        || (ret = dcc_x_file(out_fd, err_fname, "SERR", compr, NULL))
+        || (ret = dcc_x_file(out_fd, out_fname, "SOUT", compr, NULL))
         || WIFSIGNALED(status)
         || WEXITSTATUS(status)) {
         /* Something went wrong, so send DOTO 0 */
         dcc_x_token_int(out_fd, "DOTO", 0);
     } else {
-        ret = dcc_x_file(out_fd, temp_o, "DOTO", compr);
+        ret = dcc_x_file(out_fd, temp_o, "DOTO", compr, NULL);
     }
 
-    dcc_critique_status(status, argv[0], dcc_hostdef_local, 0);
+    dcc_critique_status(status, argv[0], orig_input, dcc_hostdef_local, 0);
     tcp_cork_sock(out_fd, 0);
 
     rs_log(RS_LOG_INFO|RS_LOG_NONAME, "job complete");
