@@ -2,7 +2,7 @@
  * 
  * distcc -- A simple distributed compiler system
  *
- * Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+ * Copyright (C) 2002, 2003, 2004 by Martin Pool <mbp@samba.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,7 +31,7 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "setuid.h"
+#include "daemon.h"
 #include "exitcode.h"
 
 
@@ -107,21 +107,22 @@ int dcc_discard_root(void)
     /* GNU C Library Manual says that when run by root, setgid() and setuid()
      * permanently discard privileges: both the real and effective uid are
      * set. */
- 
-#ifdef HAVE_SETGROUPS
-    /* Get rid of any supplementary groups this process might have
-     * inherited. */
-    if (setgroups(0, NULL)) {
-        rs_log_error("setgroups failed: %s", strerror(errno));
-        return EXIT_SETUID_FAILED;
-    }
-#endif
 
     if (setgid(gid)) {
         rs_log_error("setgid(%d) failed: %s", (int) gid, strerror(errno));
         return EXIT_SETUID_FAILED;
     }
 
+#ifdef HAVE_SETGROUPS
+    /* Get rid of any supplementary groups this process might have
+     * inherited. */
+    /* XXX: OS X Jaguar broke setgroups so that setting it to 0 fails. */
+    if (setgroups(1, &gid)) {
+        rs_log_error("setgroups failed: %s", strerror(errno));
+        return EXIT_SETUID_FAILED;
+    }
+#endif
+
     if (setuid(uid)) {
         rs_log_error("setuid(%d) failed: %s", (int) uid, strerror(errno));
         return EXIT_SETUID_FAILED;
