@@ -40,14 +40,11 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "rpc.h"
 #include "exitcode.h"
 #include "dopt.h"
-#include "filename.h"
 #include "hosts.h"
-#include "arg.h"
 
 
 int dcc_r_request_header(int ifd,
