@@ -35,19 +35,15 @@
 #include "types.h"
 #include "distcc.h"
 #include "rpc.h"
-#include "io.h"
 #include "trace.h"
 #include "exitcode.h"
-#include "state.h"
-#include "tempfile.h"
-#include "filename.h"
 #include "snprintf.h"
 #include "util.h"
 
 const char *dcc_state_prefix = "binstate_";
 
 
-struct dcc_history my_state;
+struct dcc_task_state my_state;
 
 
 /**
@@ -107,24 +103,24 @@ static int dcc_get_state_filename(char **fname)
 }
 
 
-const char *dcc_get_state_name(enum dcc_state state)
+const char *dcc_get_phase_name(enum dcc_phase phase)
 {
-    switch (state) {
-    case DCC_STATE_STARTUP:
+    switch (phase) {
+    case DCC_PHASE_STARTUP:
         return "Startup";
-    case DCC_STATE_BLOCKED:
+    case DCC_PHASE_BLOCKED:
         return "Blocked";
-    case DCC_STATE_COMPILE:
+    case DCC_PHASE_COMPILE:
         return "Compile";
-    case DCC_STATE_CPP:
+    case DCC_PHASE_CPP:
         return "Preprocess";
-    case DCC_STATE_CONNECT:
+    case DCC_PHASE_CONNECT:
         return "Connect";
-    case DCC_STATE_SEND:
+    case DCC_PHASE_SEND:
         return "Send";
-    case DCC_STATE_RECEIVE:
+    case DCC_PHASE_RECEIVE:
         return "Receive";
-    case DCC_STATE_DONE:
+    case DCC_PHASE_DONE:
         return "Done";
     default:
         return "Unknown";
@@ -174,6 +170,8 @@ void dcc_remove_state_file (void)
     }
 
     free(fname);
+
+    (void) ret;
 }
 
 
@@ -199,7 +197,7 @@ static int dcc_write_state(int fd)
  * If the source_file or host are NULL, then are left unchanged from
  * their previous value.
  **/
-int dcc_note_state(enum dcc_state state,
+int dcc_note_state(enum dcc_phase state,
                    const char *source_file,
                    const char *host)
 {
@@ -228,7 +226,7 @@ int dcc_note_state(enum dcc_state state,
         rs_log_error("gettimeofday failed: %s", strerror(errno));
         return EXIT_DISTCC_FAILED;
     }
-    my_state.curr_state = state;
+    my_state.curr_phase = state;
 
     rs_trace("note state %d, file \"%s\", host \"%s\"",
              state,
