@@ -34,11 +34,8 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
-#include "strip.h"
-#include "arg.h"
 
 /**
  * Strip arguments like -D and -I from a command line, because they do
