@@ -46,7 +46,6 @@
 #include "distcc.h"
 #include "trace.h"
 #include "util.h"
-#include "tempfile.h"
 #include "snprintf.h"
 #include "exitcode.h"
 
@@ -86,7 +85,7 @@
  **/
 
 
-static int dcc_get_tmp_top(const char **p_ret)
+int dcc_get_tmp_top(const char **p_ret)
 {
     const char *d;
 
