@@ -49,8 +49,6 @@
 #include "distcc.h"
 #include "trace.h"
 #include "util.h"
-#include "tempfile.h"
-#include "io.h"
 #include "exitcode.h"
 #include "snprintf.h"
 #include "lock.h"
