@@ -20,11 +20,6 @@
  * USA
  */
 
-#ifndef HAVE_SOCKLEN_T
-#define HAVE_SOCKLEN_T
-typedef size_t socklen_t;
-#endif
-
 #ifndef HAVE_IN_PORT_T
 #define HAVE_IN_PORT_T
 typedef int in_port_t;
