@@ -42,19 +42,17 @@
 
 #include "distcc.h"
 #include "trace.h"
-#include "io.h"
 #include "util.h"
 #include "exitcode.h"
 #include "snprintf.h"
 
-
 			/* I will make a man more precious than fine
 			 * gold; even a man than the golden wedge of
 			 * Ophir.
 			 *		-- Isaiah 13:12 */
 
 
-int dcc_exit(int exitcode)
+void dcc_exit(int exitcode)
 {
     struct rusage self_ru, children_ru;
 
@@ -219,6 +217,11 @@ int dcc_ignore_sigpipe(int val)
 }
 
 /**
+ * Search through the $PATH looking for a directory containing a file called
+ * @p compiler_name, which is a symbolic link containing the string "distcc".
+ *
+ * Trim the path to just after the *last* such directory.
+ *
  * If we find a distcc masquerade dir on the PATH, remove all the dirs up
  * to that point.
  **/
@@ -227,7 +230,7 @@ int dcc_trim_path(const char *compiler_name)
     const char *envpath, *newpath, *p, *n;
     char linkbuf[MAXPATHLEN], *buf;
     struct stat sb;
-    int len;
+    size_t len;
 
     if (!(envpath = getenv("PATH"))) {
         rs_trace("PATH seems not to be defined");
@@ -235,6 +238,7 @@ int dcc_trim_path(const char *compiler_name)
     }
 
     rs_trace("original PATH %s", envpath);
+    rs_trace("looking for \"%s\"", compiler_name);
 
     /* Allocate a buffer that will let us append "/cc" onto any PATH
      * element, even if there is only one item in the PATH. */
@@ -315,7 +319,7 @@ char *dcc_abspath(const char *path, int path_len)
 #endif
         len = strlen(buf);
         if (len >= sizeof buf) {
-            rs_fatal("getwd overflowed in dcc_abspath()");
+            rs_log_crit("getwd overflowed in dcc_abspath()");
         }
         buf[len++] = '/';
     }
@@ -384,3 +388,18 @@ int dcc_remove_if_exists(const char *fname)
 }
 
 
+#ifndef HAVE_STRLCPY
+/* like strncpy but does not 0 fill the buffer and always null 
+   terminates. bufsize is the size of the destination buffer */
+ size_t strlcpy(char *d, const char *s, size_t bufsize)
+{
+	size_t len = strlen(s);
+	size_t ret = len;
+	if (bufsize <= 0) return 0;
+	if (len >= bufsize) len = bufsize-1;
+	memcpy(d, s, len);
+	d[len] = 0;
+	return ret;
+}
+#endif
+
