@@ -22,7 +22,6 @@
 
 /* where.c */
 int dcc_pick_host_from_list(struct dcc_hostdef **,
-                            int *xmit_lock_fd,
                             int *cpu_lock_fd);
 
-int dcc_lock_local(int *xmit_lock_fd, int *cpu_lock_fd);
+int dcc_lock_local(int *cpu_lock_fd);
