@@ -1,6 +1,6 @@
 #! /usr/bin/env python2.2
 
-# Copyright (C) 2002, 2003 by Martin Pool <mbp@samba.org>
+# Copyright (C) 2002, 2003, 2004 by Martin Pool <mbp@samba.org>
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -21,8 +21,6 @@
 
 This script is called with $PATH pointing to the appropriate location
 for the built (or installed) programs to be tested.
-
-Copyright (C) 2002, 2003 by Martin Pool
 """
 
 
@@ -43,6 +41,8 @@ Copyright (C) 2002, 2003 by Martin Pool
 
 # TODO: Some kind of direct test of the host selection algorithm.
 
+# TODO: Test host files containing \r.
+
 # TODO: Optionally run all discc tests under Valgrind, ElectricFence
 # or something similar.
 
@@ -156,8 +156,6 @@ Copyright (C) 2002, 2003 by Martin Pool
 
 # TODO: Test lzo is parsed properly
 
-# TODO: Test compilation over LZO
-
 # TODO: Test with DISTCC_DIR set, and not set.
 
 
@@ -177,6 +175,8 @@ EXIT_BAD_HOSTSPEC            = 106
 EXIT_COMPILER_MISSING        = 110
 EXIT_ACCESS_DENIED           = 113
 
+_gcc                         = None     # full path to gcc
+
 class SimpleDistCC_Case(comfychair.TestCase):
     '''Abstract base class for distcc tests'''
     def setup(self):
@@ -192,6 +192,9 @@ class SimpleDistCC_Case(comfychair.TestCase):
                 # subprocesses may get confused.
                 del os.environ[key]
         os.environ['TMPDIR'] = self.tmpdir
+        ddir = os.path.join(self.tmpdir, 'distccdir')
+        os.mkdir(ddir)
+        os.environ['DISTCC_DIR'] = ddir
 
 
 class WithDaemon_Case(SimpleDistCC_Case):
@@ -289,7 +292,7 @@ class VersionOption_Case(SimpleDistCC_Case):
             out, err = self.runcmd("%s --version" % prog)
             assert out[-1] == '\n'
             out = out[:-1]
-            line1,trash = string.split(out, '\n')
+            line1,trash = string.split(out, '\n', 1)
             self.assert_re_match(r'^%s [\w.-]+ [.\w-]+ \(protocol.*\) \(default port 3632\)$'
                                  % prog, line1)
 
@@ -307,14 +310,15 @@ class BogusOption_Case(SimpleDistCC_Case):
 
     Now that we support implicit compilers, this is passed to gcc, which returns 1."""
     def runtest(self):
-        self.runcmd("distcc --bogus-option", 1)
-        self.runcmd("distccd --bogus-option", EXIT_BAD_ARGUMENTS)
+        self.runcmd("distcc " + _gcc + " --bogus-option", 1)
+        self.runcmd("distccd " + _gcc + " --bogus-option", EXIT_BAD_ARGUMENTS)
 
 
 class GccOptionsPassed_Case(SimpleDistCC_Case):
     """Test that options following the compiler name are passed to the compiler."""
     def runtest(self):
-        out, err = self.runcmd("DISTCC_HOSTS=localhost distcc gcc --help")
+        out, err = self.runcmd("DISTCC_HOSTS=localhost distcc " + \
+                               _gcc + " --help")
         if re.search('distcc', out):
             raise ("gcc help contains \"distcc\": \"%s\"" % out)
         self.assert_re_match(r"^Usage: gcc", out)
@@ -406,8 +410,17 @@ class ScanArgs_Case(SimpleDistCC_Case):
                  ("foo.c -o foo.o -c", "distribute", "foo.c", "foo.o"),
 
                  # Produce assembly listings
-                 ("gcc -Wa,-alh -c foo.c", "distribute", "foo.c", "foo.o"),
                  ("gcc -Wa,-alh,-a=foo.lst -c foo.c", "local"),
+                 ("gcc -Wa,--MD -c foo.c", "local"),
+                 ("gcc -Wa,-xarch=v8 -c foo.c", "distribute", "foo.c", "foo.o"),
+
+                 # Produce .rpo files
+                 ("g++ -frepo foo.C", "local"),
+
+                 ("gcc -xassembler-with-cpp -c foo.c", "local"),
+                 ("gcc -x assembler-with-cpp -c foo.c", "local"),
+
+                 ("gcc -specs=foo.specs -c foo.c", "local"),
                  ]
         for tup in cases:
             apply(self.checkScanArgs, tup)
@@ -485,13 +498,15 @@ class ParseHostSpec_Case(SimpleDistCC_Case):
         angry:300/44
         angry/44:300
         angry,lzo
-        angry:3000,lzo
+        angry:3000,lzo    # some comment
         angry/44,lzo
-        @angry,lzo
+        @angry,lzo#asdasd
+        # oh yeah nothing here
         @angry:/usr/sbin/distccd,lzo
+        localhostbutnotreally
         """
 
-        expected="""15
+        expected="""16
    2 LOCAL
    4 TCP 127.0.0.1 3632
    4 SSH (no-user) angry (no-command)
@@ -507,6 +522,7 @@ class ParseHostSpec_Case(SimpleDistCC_Case):
   44 TCP angry 3632
    4 SSH (no-user) angry (no-command)
    4 SSH (no-user) angry /usr/sbin/distccd
+   4 TCP localhostbutnotreally 3632
 """
         out, err = self.runcmd("DISTCC_HOSTS=\"%s\" h_hosts" % spec)
         assert out == expected, "expected %s\ngot %s" % (`expected`, `out`)
@@ -550,10 +566,11 @@ class Compilation_Case(WithDaemon_Case):
 
     def compileCmd(self):
         """Return command to compile source and run tests"""
-        return "DISTCC_FALLBACK=0 distcc cc -o testtmp.o -c %s" % (self.sourceFilename())
+        return "DISTCC_FALLBACK=0 distcc " + \
+               _gcc + " -o testtmp.o -c %s" % (self.sourceFilename())
 
     def linkCmd(self):
-        return "distcc cc -o testtmp testtmp.o"
+        return "distcc " + _gcc + " -o testtmp testtmp.o"
 
     def checkCompileMsgs(self, msgs):
         if msgs <> '':
@@ -586,17 +603,55 @@ int main(void) {
         self.assert_equal(msgs, "hello world\n")
 
 
+
+class CompressedCompile_Case(Compilation_Case):
+    """Test compilation with compression.
+
+    The source needs to be moderately large to make sure compression and mmap
+    is turned on."""
+
+    def source(self):
+        return """
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+int main(void) {
+    printf("hello world\\n");
+    return 0;
+}
+"""
+
+    def setupEnv(self):
+        Compilation_Case.setupEnv(self)
+        os.environ['DISTCC_HOSTS'] = '127.0.0.1:%d,lzo' % self.server_port
+        
+    
+    def checkBuiltProgramMsgs(self, msgs):
+        self.assert_equal(msgs, "hello world\n")
+
+
+
 class DashONoSpace_Case(CompileHello_Case):
     def compileCmd(self):
-        return "DISTCC_FALLBACK=0 distcc cc -otesttmp.o -c %s" % (self.sourceFilename())
+        return "DISTCC_FALLBACK=0 distcc " + _gcc + \
+               " -otesttmp.o -c %s" % (self.sourceFilename())
 
+    def runtest(self):
+        if sys.platform == 'sunos5':
+            raise comfychair.NotRunError ('Sun assembler wants space after -o')
+        elif sys.platform.startswith ('osf1'):
+            raise comfychair.NotRunError ('GCC mips-tfile wants space after -o')
+        else:
+            CompileHello_Case.runtest (self)
 
 class WriteDevNull_Case(CompileHello_Case):
     def runtest(self):
         self.compile()
         
     def compileCmd(self):
-        return "DISTCC_FALLBACK=0 distcc -c -o /dev/null -c %s" % (self.sourceFilename())
+        return "DISTCC_FALLBACK=0 distcc " + _gcc + \
+               " -c -o /dev/null -c %s" % (self.sourceFilename())
 
 
 class MultipleCompile_Case(Compilation_Case):
@@ -614,8 +669,8 @@ int main(void) {
 """)
         
     def runtest(self):
-        self.runcmd("distcc cc -c test1.c test2.c")
-        self.runcmd("distcc cc -o test test1.o test2.o")
+        self.runcmd("distcc " + _gcc + " -c test1.c test2.c")
+        self.runcmd("distcc " + _gcc + " -o test test1.o test2.o")
         
 
 
@@ -625,7 +680,7 @@ class CppError_Case(CompileHello_Case):
         return '#error "not tonight dear"\n'
 
     def runtest(self):
-        cmd = "distcc -c testtmp.c"
+        cmd = "distcc " + _gcc + " -c testtmp.c"
         msgs, errs = self.runcmd(cmd, expectedResult=1)
         self.assert_re_search("not tonight dear", errs)
         self.assert_equal(msgs, '')
@@ -638,7 +693,7 @@ class BadInclude_Case(Compilation_Case):
 """
 
     def runtest(self):
-        self.runcmd("distcc cc -o testtmp.o -c testtmp.c", 1)
+        self.runcmd("distcc " + _gcc + " -o testtmp.o -c testtmp.c", 1)
 
 
 class PreprocessPlainText_Case(Compilation_Case):
@@ -659,7 +714,7 @@ large foo!
 
     def runtest(self):
         # -P means not to emit linemarkers
-        self.runcmd("distcc gcc -E testtmp.c -o testtmp.out")
+        self.runcmd("distcc " + _gcc + " -E testtmp.c -o testtmp.out")
         out = open("testtmp.out").read()
         # It's a bit hard to know the exact value, because different versions of
         # GNU cpp seem to handle the whitespace differently.
@@ -697,7 +752,13 @@ class ImplicitCompiler_Case(CompileHello_Case):
         # FIXME: Mozilla uses something like "distcc testtmp.o -o testtmp",
         # but that's broken at the moment.
         return "distcc -o testtmp testtmp.o "
-        
+
+    def runtest(self):
+        if sys.platform != 'hp-ux10':
+            CompileHello_Case.runtest (self)
+        else:
+            raise comfychair.NotRunError ('HP-UX bundled C compiler non-ANSI')
+
 
 class DashD_Case(Compilation_Case):
     """Test preprocessor arguments"""
@@ -713,7 +774,8 @@ int main(void) {
 
     def compileCmd(self):
         # quoting is hairy because this goes through the shell
-        return "distcc cc -c -o testtmp.o '-DMESSAGE=\"hello world\"' testtmp.c"
+        return "distcc " + _gcc + \
+               " -c -o testtmp.o '-DMESSAGE=\"hello world\"' testtmp.c"
 
     def checkBuiltProgramMsgs(self, msgs):
         self.assert_equal(msgs, "hello world\n")
@@ -727,7 +789,7 @@ class ThousandFold_Case(CompileHello_Case):
     def runtest(self):
         # may take about a minute or so
         for i in xrange(1000):
-            self.runcmd("distcc cc -o testtmp.o -c testtmp.c")
+            self.runcmd("distcc " + _gcc + " -o testtmp.o -c testtmp.c")
 
 
 class Concurrent_Case(CompileHello_Case):
@@ -738,8 +800,9 @@ class Concurrent_Case(CompileHello_Case):
     def runtest(self):
         # may take about a minute or so
         pids = {}
-        for i in xrange(100):
-            kid = self.runcmd_background("distcc cc -o testtmp.o -c testtmp.c")
+        for i in xrange(50):
+            kid = self.runcmd_background("distcc " + _gcc + \
+                                         " -o testtmp.o -c testtmp.c")
             pids[kid] = kid
         while len(pids):
             pid, status = os.wait()
@@ -767,8 +830,8 @@ class BigAssFile_Case(Compilation_Case):
         f.close()
 
     def runtest(self):
-        self.runcmd("distcc cc -c %s" % "testtmp.c")
-        self.runcmd("distcc cc -o testtmp testtmp.o")
+        self.runcmd("distcc " + _gcc + " -c %s" % "testtmp.c")
+        self.runcmd("distcc " + _gcc + " -o testtmp testtmp.o")
 
 
     def daemon_lifetime(self):
@@ -792,7 +855,12 @@ class BinFalse_Case(Compilation_Case):
         open("testtmp.i", "wt").write("int main() {}")
         
     def runtest(self):
-        self.runcmd("distcc false -c testtmp.i", 1)
+        # On Solaris and IRIX 6, 'false' returns exit status 255
+        if sys.platform == 'sunos5' or \
+        sys.platform.startswith ('irix6'):
+            self.runcmd("distcc false -c testtmp.i", 255)
+        else:
+            self.runcmd("distcc false -c testtmp.i", 1)
 
 
 class BinTrue_Case(Compilation_Case):
@@ -821,7 +889,7 @@ class SBeatsC_Case(CompileHello_Case):
     output filename in the same way as gcc."""
     # XXX: Are other compilers the same?
     def runtest(self):
-        self.runcmd("distcc gcc -c -S testtmp.c")
+        self.runcmd("distcc " + _gcc + " -c -S testtmp.c")
         if os.path.exists("testtmp.o"):
             self.fail("created testtmp.o but should not have")
         if not os.path.exists("testtmp.s"):
@@ -838,7 +906,7 @@ class NoServer_Case(CompileHello_Case):
         self.createSource()
     
     def runtest(self):
-        self.runcmd("distcc gcc -c -o testtmp.o testtmp.c")
+        self.runcmd("distcc " + _gcc + " -c -o testtmp.o testtmp.c")
         msgs = open(self.distcc_log, 'r').read()
         self.assert_re_search(r'failed to distribute.*running locally instead',
                               msgs)            
@@ -847,7 +915,7 @@ class NoServer_Case(CompileHello_Case):
 class ImpliedOutput_Case(CompileHello_Case):
     """Test handling absence of -o"""
     def compileCmd(self):
-        return "distcc cc -c testtmp.c"
+        return "distcc " + _gcc + " -c testtmp.c"
 
 
 class SyntaxError_Case(Compilation_Case):
@@ -894,7 +962,8 @@ class NoHosts_Case(CompileHello_Case):
 
     def compileCmd(self):
         """Return command to compile source and run tests"""
-        return "DISTCC_FALLBACK=1 distcc cc -o testtmp.o -c %s" % (self.sourceFilename())
+        return "DISTCC_FALLBACK=1 distcc " + _gcc + \
+               " -o testtmp.o -c %s" % (self.sourceFilename())
 
 
 
@@ -912,11 +981,11 @@ class MissingCompiler_Case(CompileHello_Case):
     def runtest(self):
         msgs, errs = self.runcmd("DISTCC_FALLBACK=0 distcc nosuchcc -c testtmp.i",
                                  expectedResult=EXIT_COMPILER_MISSING)
-        self.assert_re_search(r'failed to exec.*No such file or directory', errs)
+        self.assert_re_search(r'failed to exec', errs)
         
 
 
-class RemoteAssemble_Case(CompileHello_Case):
+class RemoteAssemble_Case(WithDaemon_Case):
     """Test remote assembly of a .s file."""
 
     # We have a rather tricky method for testing assembly code when we
@@ -924,8 +993,6 @@ class RemoteAssemble_Case(CompileHello_Case):
     # everywhere, though perhaps not.
     asm_source = """
         .file	"foo.c"
-	.version	"01.01"
-gcc2_compiled.:
 .globl msg
 .section	.rodata
 .LC0:
@@ -936,42 +1003,21 @@ gcc2_compiled.:
 	.size	 msg,4
 msg:
 	.long .LC0
-	.ident	"GCC: (GNU) 2.95.4 20011002 (Debian prerelease)"
 """
 
-    def source(self):
-            return """
-#include <stdio.h>
-
-extern const char *msg;
-
-int main(void) {
-    puts(msg);
-    return 0;
-}
-"""
     asm_filename = 'test2.s'
 
     def setup(self):
-        CompileHello_Case.setup(self)
+        WithDaemon_Case.setup(self)
         open(self.asm_filename, 'wt').write(self.asm_source)
-        
-        # TODO: Delete temp files
 
     def compile(self):
         # Need to build both the C file and the assembly file
-        self.runcmd("distcc cc -o test2.o -c test2.s")
-        self.runcmd("distcc cc -o testtmp.o -c testtmp.c")
-        self.runcmd(self.linkCmd())
-
-    def asmCmd(self):
-        return "distcc cc -o test2.o -c %s" % (self.asm_filename)
-
-    def linkCmd(self):
-        return "distcc cc -o testtmp testtmp.o test2.o"
+        self.runcmd("distcc " + _gcc + " -o test2.o -c test2.s")
 
 
-class PreprocessAsm_Case(RemoteAssemble_Case):
+
+class PreprocessAsm_Case(WithDaemon_Case):
     """Run preprocessor locally on assembly, then compile locally."""
     asm_source = """
 #define MSG "hello world"
@@ -987,18 +1033,25 @@ gcc2_compiled.:
 msg:
 	.long .LC0
 """
-    asm_filename = 'test2.S'
+
+    def setup(self):
+        WithDaemon_Case.setup(self)
+        open('test2.S', 'wt').write(self.asm_source)
     
     def compile(self):
-        self.runcmd("distcc cc -o test2.o -c test2.S")
-        self.runcmd("distcc cc -o testtmp.o -c testtmp.c")
-        self.runcmd("distcc cc -o testtmp testtmp.o test2.o")
+        if sys.platform == 'linux2':
+            self.runcmd("distcc -o test2.o -c test2.S")
+
+    def runtest(self):
+        self.compile()
+
+
 
 
 class ModeBits_Case(CompileHello_Case):
     """Check distcc obeys umask"""
     def runtest(self):
-        self.runcmd("umask 0; distcc -c testtmp.c")
+        self.runcmd("umask 0; distcc " + _gcc + " -c testtmp.c")
         self.assert_equal(S_IMODE(os.stat("testtmp.o")[ST_MODE]), 0666)
 
 
@@ -1021,7 +1074,7 @@ class EmptySource_Case(Compilation_Case):
         self.compile()
 
     def compile(self):
-        self.runcmd("distcc cc -c %s" % self.sourceFilename())
+        self.runcmd("distcc " + _gcc + " -c %s" % self.sourceFilename())
 
     def sourceFilename(self):
         return "testtmp.i"
@@ -1030,8 +1083,8 @@ class BadLogFile_Case(comfychair.TestCase):
     def runtest(self):
         self.runcmd("touch distcc.log")
         self.runcmd("chmod 0 distcc.log")
-        msgs, errs = self.runcmd("DISTCC_LOG=distcc.log distcc -c foo.c",
-                                expectedResult=1)
+        msgs, errs = self.runcmd("DISTCC_LOG=distcc.log distcc " + \
+                                 _gcc + " -c foo.c", expectedResult=1)
         self.assert_re_search("failed to open logfile", errs)
 
 
@@ -1047,7 +1100,7 @@ class AccessDenied_Case(CompileHello_Case):
 
     def compileCmd(self):
         """Return command to compile source and run tests"""
-        return "DISTCC_FALLBACK=1 distcc cc -o testtmp.o -c %s" % (self.sourceFilename())
+        return "DISTCC_FALLBACK=1 distcc " + _gcc + " -o testtmp.o -c %s" % (self.sourceFilename())
 
     
     def runtest(self):
@@ -1066,7 +1119,7 @@ class ParseMask_Case(comfychair.TestCase):
         ('10.113.0.0/16', '10.113.45.67', 0),
         ('10.113.0.0/16', '10.11.45.67', EXIT_ACCESS_DENIED),
         ('10.113.0.0/16', '127.0.0.1', EXIT_ACCESS_DENIED),
-        ('1.2.3.4/0', '4.3.2.1', EXIT_BAD_ARGUMENTS),
+        ('1.2.3.4/0', '4.3.2.1', 0),
         ('1.2.3.4/40', '4.3.2.1', EXIT_BAD_ARGUMENTS),
         ('1.2.3.4.5.6.7/8', '127.0.0.1', EXIT_BAD_ARGUMENTS),
         ('1.2.3.4/8', '4.3.2.1', EXIT_ACCESS_DENIED),
@@ -1087,14 +1140,22 @@ class HostFile_Case(CompileHello_Case):
         del os.environ['DISTCC_HOSTS']
         self.save_home = os.environ['HOME']
         os.environ['HOME'] = os.getcwd()
-        os.mkdir('.distcc')
-        open('.distcc/hosts', 'w').write('127.0.0.1:%d' % self.server_port)
+        # DISTCC_DIR is set to 'distccdir'
+        open(os.environ['DISTCC_DIR'] + '/hosts', 'w').write('127.0.0.1:%d' % self.server_port)
 
     def teardown(self):
         os.environ['HOME'] = self.save_home
         CompileHello_Case.teardown(self)
 
 
+# When invoking compiler, use absolute path so distccd can find it
+for path in os.environ['PATH'].split (':'):
+    abs_path = os.path.join (path, 'gcc')
+
+    if os.path.isfile (abs_path):
+        _gcc = abs_path
+        break
+
 # All the tests defined in this suite
 tests = [BadLogFile_Case,
          ScanArgs_Case,
@@ -1103,6 +1164,7 @@ tests = [BadLogFile_Case,
          StripArgs_Case,
          StartStopDaemon_Case,
          CompileHello_Case,
+         CompressedCompile_Case,
          DashONoSpace_Case,
          WriteDevNull_Case,
          CppError_Case,
